==> react-native-web-jsonschema-form-1.0.28.tgz: package/widgets/ArrayWidget/Item.js <==
import _get from "lodash/get";
import _noop from "lodash/noop";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet, Platform, View as RNView } from 'react-native';
import View from 'react-native-web-ui-components/View';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import RemoveHandle from './RemoveHandle';
const styles = StyleSheet.create({
  main: {
    flex: 1
  },
  row: {
    flexDirection: 'row'
  },
  container: {
    width: '100%',
    alignItems: 'flex-start'
  }
});

const Wrapper = ({
  children,
  style,
  itemStyle,
  zIndex,
  uiSchema,
  ...props
}) => {
  if (Platform.OS === 'web') {
    const topStyle = StyleSheet.flatten([styles.container, _get(uiSchema, ['ui:widgetProps', 'style'], null)]);
    const css = {
      display: 'flex',
      alignItems: 'flex-start',
      width: topStyle.width === undefined ? 'max-content' : '100%',
      flexDirection: 'row',
      zIndex,
      ...StyleSheet.flatten(itemStyle),
      ...style
    };
    return React.createElement('div', { ...props,
      style: css
    }, children);
  }

  return React.createElement(View, {
    style: [styles.row, itemStyle, zIndex]
  }, children);
};

Wrapper.propTypes = {
  uiSchema: PropTypes.shape().isRequired,
  zIndex: PropTypes.number.isRequired,
  value: PropTypes.arrayOf(PropTypes.any).isRequired,
  index: PropTypes.number.isRequired,
  children: PropTypes.node.isRequired,
  style: StylePropType,
  itemStyle: StylePropType
};
Wrapper.defaultProps = {
  style: {},
  itemStyle: {}
};

const Item = ({
  onItemRef,
  panHandlers,
  style,
  zIndex,
  itemStyle,
  onMouseDown,
  onTouchStart,
  onMouseUp,
  onTouchEnd,
  onClick,
  propertyName,
  propertyValue,
  propertySchema,
  propertyMeta,
  propertyErrors,
  PropertyField,
  RemoveComponent,
  OrderComponent,
  ...props
}) => {
  const {
    value,
    index,
    auto,
    removable,
    orderable,
    screenType,
    propertyUiSchema
  } = props;
  return React.createElement(React.Fragment, null, React.createElement(Wrapper, {
    itemStyle: itemStyle,
    style: style,
    value: value,
    index: index,
    zIndex: zIndex,
    onMouseDown: onMouseDown,
    onTouchStart: onTouchStart,
    onMouseUp: onMouseUp,
    onTouchEnd: onTouchEnd,
    onClick: onClick
  }, orderable ? React.createElement(OrderComponent, _extends({}, props, {
    panHandlers: panHandlers
  })) : null, React.createElement(RNView, {
    ref: onItemRef,
    style: auto ? null : styles.main
  }, React.createElement(PropertyField, _extends({}, props, {
    name: propertyName,
    schema: propertySchema,
    uiSchema: propertyUiSchema,
    errors: propertyErrors,
    value: propertyValue,
    meta: propertyMeta
  }))), removable && (screenType !== 'xs' || RemoveComponent !== RemoveHandle) ? React.createElement(RemoveComponent, props) : null), removable && screenType === 'xs' && RemoveComponent === RemoveHandle ? React.createElement(RemoveComponent, props) : null);
};

Item.propTypes = {
  value: PropTypes.arrayOf(PropTypes.any).isRequired,
  index: PropTypes.number.isRequired,
  zIndex: PropTypes.number.isRequired,
  focus: PropTypes.string.isRequired,
  screenType: PropTypes.string.isRequired,
  propertyName: PropTypes.string.isRequired,
  propertySchema: PropTypes.shape().isRequired,
  propertyUiSchema: PropTypes.shape().isRequired,
  propertyMeta: PropTypes.any.isRequired,
  // eslint-disable-line
  orderable: PropTypes.bool.isRequired,
  removable: PropTypes.bool.isRequired,
  OrderComponent: PropTypes.elementType.isRequired,
  RemoveComponent: PropTypes.elementType.isRequired,
  PropertyField: PropTypes.elementType.isRequired,
  onItemRef: PropTypes.func.isRequired,
  panHandlers: PropTypes.shape(),
  auto: PropTypes.bool,
  style: StylePropType,
  itemStyle: StylePropType,
  onMouseDown: PropTypes.func,
  onMouseUp: PropTypes.func,
  onTouchStart: PropTypes.func,
  onTouchEnd: PropTypes.func,
  onClick: PropTypes.func,
  propertyValue: PropTypes.any,
  // eslint-disable-line
  propertyErrors: PropTypes.any // eslint-disable-line

};
Item.defaultProps = {
  panHandlers: {},
  auto: false,
  style: null,
  itemStyle: null,
  onMouseDown: _noop,
  onMouseUp: _noop,
  onTouchStart: _noop,
  onTouchEnd: _noop,
  onClick: _noop,
  propertyErrors: undefined
};
export default Item;

==> react-native-web-jsonschema-form-1.1.11.tgz: package/widgets/ArrayWidget/Item.js <==
import _get from "lodash/get";
import _noop from "lodash/noop";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet, Platform, View as RNView } from 'react-native';
import View from 'react-native-web-ui-components/View';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import RemoveHandle from './RemoveHandle';
const styles = StyleSheet.create({
  main: {
    flex: 1
  },
  row: {
    flexDirection: 'row'
  },
  container: {
    width: '100%',
    alignItems: 'flex-start'
  }
});

const Wrapper = ({
  children,
  style,
  itemStyle,
  zIndex,
  uiSchema,
  ...props
}) => {
  if (Platform.OS === 'web') {
    const topStyle = StyleSheet.flatten([styles.container, _get(uiSchema, ['ui:widgetProps', 'style'], null)]);
    const css = {
      display: 'flex',
      alignItems: 'flex-start',
      width: topStyle.width === undefined ? 'max-content' : '100%',
      flexDirection: 'row',
      zIndex,
      ...StyleSheet.flatten(itemStyle),
      ...style
    };
    return React.createElement('div', { ...props,
      style: css
    }, children);
  }

  return React.createElement(View, {
    style: [styles.row, itemStyle, zIndex]
  }, children);
};

Wrapper.propTypes = {
  zIndex: PropTypes.number.isRequired,
  value: PropTypes.arrayOf(PropTypes.any).isRequired,
  index: PropTypes.number.isRequired,
  children: PropTypes.node.isRequired,
  uiSchema: PropTypes.shape(),
  style: StylePropType,
  itemStyle: StylePropType
};
Wrapper.defaultProps = {
  style: {},
  itemStyle: {},
  uiSchema: {}
};

const Item = ({
  onItemRef,
  panHandlers,
  style,
  zIndex,
  itemStyle,
  onMouseDown,
  onTouchStart,
  onMouseUp,
  onTouchEnd,
  onClick,
  propertyName,
  propertyValue,
  propertySchema,
  propertyMeta,
  propertyErrors,
  PropertyField,
  RemoveComponent,
  OrderComponent,
  ...props
}) => {
  const {
    value,
    index,
    auto,
    removable,
    orderable,
    screenType,
    propertyUiSchema
  } = props;
  return React.createElement(React.Fragment, null, React.createElement(Wrapper, {
    itemStyle: itemStyle,
    style: style,
    value: value,
    index: index,
    zIndex: zIndex,
    onMouseDown: onMouseDown,
    onTouchStart: onTouchStart,
    onMouseUp: onMouseUp,
    onTouchEnd: onTouchEnd,
    onClick: onClick
  }, orderable ? React.createElement(OrderComponent, _extends({}, props, {
    panHandlers: panHandlers
  })) : null, React.createElement(RNView, {
    ref: onItemRef,
    style: auto ? null : styles.main
  }, React.createElement(PropertyField, _extends({}, props, {
    name: propertyName,
    schema: propertySchema,
    uiSchema: propertyUiSchema,
    errors: propertyErrors,
    value: propertyValue,
    meta: propertyMeta
  }))), removable && (screenType !== 'xs' || RemoveComponent !== RemoveHandle) ? React.createElement(RemoveComponent, props) : null), removable && screenType === 'xs' && RemoveComponent === RemoveHandle ? React.createElement(RemoveComponent, props) : null);
};

Item.propTypes = {
  value: PropTypes.arrayOf(PropTypes.any).isRequired,
  index: PropTypes.number.isRequired,
  zIndex: PropTypes.number.isRequired,
  focus: PropTypes.string.isRequired,
  screenType: PropTypes.string.isRequired,
  propertyName: PropTypes.string.isRequired,
  propertySchema: PropTypes.shape().isRequired,
  propertyUiSchema: PropTypes.shape().isRequired,
  propertyMeta: PropTypes.any.isRequired,
  // eslint-disable-line
  orderable: PropTypes.bool.isRequired,
  removable: PropTypes.bool.isRequired,
  OrderComponent: PropTypes.elementType.isRequired,
  RemoveComponent: PropTypes.elementType.isRequired,
  PropertyField: PropTypes.elementType.isRequired,
  onItemRef: PropTypes.func.isRequired,
  panHandlers: PropTypes.shape(),
  auto: PropTypes.bool,
  style: StylePropType,
  itemStyle: StylePropType,
  onMouseDown: PropTypes.func,
  onMouseUp: PropTypes.func,
  onTouchStart: PropTypes.func,
  onTouchEnd: PropTypes.func,
  onClick: PropTypes.func,
  propertyValue: PropTypes.any,
  // eslint-disable-line
  propertyErrors: PropTypes.any // eslint-disable-line

};
Item.defaultProps = {
  panHandlers: {},
  auto: false,
  style: null,
  itemStyle: null,
  onMouseDown: _noop,
  onMouseUp: _noop,
  onTouchStart: _noop,
  onTouchEnd: _noop,
  onClick: _noop,
  propertyErrors: undefined
};
export default Item;
